summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka/undoredo.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
commite985f7e545f4739493965aad69bbecb136dc9346 (patch)
tree54afd409d8acd6202dd8ab611d24e78c28e4c0a0 /quanta/parts/kafka/undoredo.h
parentf7670c198945adc3b95ad69a959fe5f8ae55b493 (diff)
downloadtdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.tar.gz
tdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.zip
TQt4 port kdewebdev
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1237029 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'quanta/parts/kafka/undoredo.h')
-rw-r--r--quanta/parts/kafka/undoredo.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/quanta/parts/kafka/undoredo.h b/quanta/parts/kafka/undoredo.h
index 390dc5bb..1bd0cff5 100644
--- a/quanta/parts/kafka/undoredo.h
+++ b/quanta/parts/kafka/undoredo.h
@@ -95,17 +95,17 @@ public:
/**
* TODO:REMOVE
* For non-XmlEnd Node deletion without its children.
* @param childrenNumber The number of children which are moved up
* at the location where was the deleted Node.
*/
- void setChildrenMovedUp(int childrenNumber) {m_childrenMovedUp = childrenNumber;}
+ void setChildrenMovedUp(int tqchildrenNumber) {m_tqchildrenMovedUp = tqchildrenNumber;}
/**
* TODO:REMOVE
* @return Returns the number of childs which were moved up.
*/
- int childrenMovedUp() {return m_childrenMovedUp;}
+ int tqchildrenMovedUp() {return m_tqchildrenMovedUp;}
/**
* TODO:REMOVE
@@ -139,7 +139,7 @@ public:
NodeTreeRemoved,
//Moving a Node from one location to another. Implemented.
NodeMoved,
//Moving a Node and its children from one location to another.
NodeAndChildsMoved
};
@@ -148,7 +148,7 @@ private:
TQValueList<int> m_location, m_finalLocation;
Node *m_node;
Tag *m_tag;
- int m_childrenMovedUp;
+ int m_tqchildrenMovedUp;
int m_neighboursMovedDown;
};
@@ -248,7 +248,7 @@ private:
* This class, basically a new undo/redo system, also helps KafkaDocument to synchronize the
* kafka and quanta view.
*/
-class undoRedo : public QObject
+class undoRedo : public TQObject
{
public:
/**
@@ -95,17 +95,17 @@ public:
/**
* TODO:REMOVE
- * For non-XmlEnd Node deletion without its children.
- * @param childrenNumber The number of children which are moved up
+ * For non-XmlEnd Node deletion without its tqchildren.
+ * @param tqchildrenNumber The number of tqchildren which are moved up
* at the location where was the deleted Node.
*/
@@ -139,7 +139,7 @@ public:
//Moving a Node from one location to another. Implemented.
NodeMoved,
- //Moving a Node and its children from one location to another.
+ //Moving a Node and its tqchildren from one location to another.
NodeAndChildsMoved
};